@@ -38,6 +38,7 @@ class PostExtractor:
     likes_regex = re.compile(r'like_def[^>]*>([0-9,.]+)')
     comments_regex = re.compile(r'cmt_def[^>]*>([0-9,.]+)')
     shares_regex = re.compile(r'([0-9,.]+)\s+Shares', re.IGNORECASE)
+    live_regex = re.compile(r'.+(is live).+')
     link_regex = re.compile(r"href=\"https:\/\/lm\.facebook\.com\/l\.php\?u=(.+?)\&amp;h=")
 
     photo_link = re.compile(r'href=\"(/[^\"]+/photos/[^\"]+?)\"')
@@ -85,6 +86,7 @@ class PostExtractor:
             'link': None,
             'user_id': None,
             'source': None,
+            'is_live': False,
         }
 
     def extract_post(self) -> Post:
@@ -104,6 +106,7 @@ class PostExtractor:
             self.extract_video,
             self.extract_video_thumbnail,
             self.extract_video_id,
+            self.extract_is_live,
         ]
 
         post = self.make_new_post()
@@ -123,7 +126,7 @@ class PostExtractor:
             except Exception as ex:
                 logger.warning("Exception while running %s: %r", method.__name__, ex)
 
-        if 'reactions' in self.options:
+        if self.options.get('reactions'):
             try:
                 reactions = self.extract_reactions()
             except Exception as ex:
@@ -156,7 +159,7 @@ class PostExtractor:
                 response = self.request(url)
                 element = response.html.find('.story_body_container', first=True)
 
-        nodes = element.find('p, header')
+        nodes = element.find('p, header, span[role=presentation]')
         if nodes:
             post_text = []
             shared_text = []
@@ -258,9 +261,12 @@ class PostExtractor:
         return None
 
     def extract_post_url(self) -> PartialPost:
-        query_params = ('story_fbid', 'id')
 
+        query_params = ('story_fbid', 'id')
+        account = self.options.get('account')
         elements = self.element.find('header a')
+        video_post_match = None
+
         for element in elements:
             href = element.attrs.get('href', '')
 
@@ -269,14 +275,22 @@ class PostExtractor:
 
             if post_match:
                 path = utils.filter_query_params(href, whitelist=query_params)
-                url = utils.urljoin(FB_BASE_URL, path)
-                return {'post_url': url}
 
             elif video_post_match:
                 video_post_id = video_post_match.group(1)
-                url = utils.urljoin(FB_BASE_URL, f'watch?v={video_post_id}')
-                return {'post_url': url}
-        return None
+
+                if account is None:
+                    path = f'watch?v={video_post_id}'
+                else:
+                    path = f'{account}/videos/{video_post_id}'
+
+        post_id = self._data_ft.get('top_level_post_id')
+
+        if video_post_match is None and account is not None and post_id is not None:
+            path = f'{account}/posts/{post_id}'
+
+        url = utils.urljoin(FB_BASE_URL, path)
+        return {'post_url': url}
 
     # TODO: Remove `or 0` from this methods
     def extract_likes(self) -> PartialPost:
@@ -361,7 +375,7 @@ class PostExtractor:
         video_data_element = self.element.find('[data-sigil="inlineVideo"]', first=True)
         if video_data_element is None:
             return None
-        if 'youtube_dl' in self.options:
+        if self.options.get('youtube_dl'):
             vid = self.extract_video_highres()
             if vid:
                 return vid
@@ -386,7 +400,7 @@ class PostExtractor:
             'format': 'best',
             'quiet': True,
         }
-        if 'youtube_dl_verbose' in self.options:
+        if self.options.get('youtube_dl_verbose'):
             ydl_opts.quiet = False
 
         try:
@@ -415,6 +429,16 @@ class PostExtractor:
             return {'video_id': match.groups()[0]}
         return None
 
+    def extract_is_live(self):
+        header = self.element.find('header')[0].full_text
+
+        match = self.live_regex.search(header)
+
+        if match is not None:
+            return {'is_live': True}
+
+        return {'is_live': False}
+
     def parse_share_and_reactions(self, html: str):
         bad_jsons = self.shares_and_reactions_regex.findall(html)
         for bad_json in bad_jsons:
